.. gmol-base documentation master file, created by
   sphinx-quickstart on Thu Sep  5 14:52:18 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

gmol-base Python API Reference
==============================

.. autosummary::
   :toctree: _autosummary
   :template: custom-module.rst
   :recursive:

   gmol.base

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
